# 만든 사람들

본 강의는 제주한라대학교 인공지능학과 이영준 교수가 직접 강의하고, 학부생들이 직접 참여하여 만들어졌습니다. 강의를 듣는 학생들은 강의를 듣는 것뿐만 아니라, 강의를 만드는 과정에 직접 참여하게 됩니다. 이를 통해 학생들은 강의를 듣는 것뿐만 아니라, 강의를 만드는 과정을 통해 실제로 배우고, 실제로 경험하게 됩니다.

## Instructor

### 이영준

```{image} https://entelecheia.me/assets/img/profile-200x220.jpeg
:width: 100
:align: left
```

- 관심분야: 인공지능, 자연어처리, Generative AI, Multimodal AI, Robotics, Sustainability
- 주요담당분야: 자연어처리, 생성형 AI, 빅데이터, DevOps & MLOps
- E-Mail: [yj.lee@chu.ac.kr](mailto:yj.lee@chu.ac.kr)
- 🏠: [entelecheia.me](https://entelecheia.me)

## Teaching Assistants

## Students

### 박은성

- 202121006
- 202121006@chu.ac.kr

### 박진우

- 학번: 202321010
- 202321010@chu.ac.kr

### 오혜진

- 202321012
- ohj-0903@naver.com

### 고다희

- 본인소개
- 본인 연락처

### 이규범

- 2024학년도 학회장입니다.
- 202221014@chu.ac.kr

### 양필성

- 202121010
- lal4995@naver.com

### 조세현

- 인공지능공학과 202321017
- 202321017@chu.ac.kr

### 김진우

- 202321007
- 202321006@chu.ac.kr

### 장희선

- 202021029
- 202021029@chu.ac.kr

### 이대건

- 202021025
- 202021025@chu.ac.kr

### 김영준

- 202321004
- 202321004@chu.ac.kr
